/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * Copyright (C) 2006-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://openbluesky.kenai.com
 * SCM: https://bitbucket.org/tidalwave/openbluesky-src
 *
 **********************************************************************************************************************/
package it.tidalwave.netbeans.examples.nodes.example6.model;

import javax.annotation.Nonnull;
import lombok.Getter;
import java.util.ArrayList;
import java.util.List;
import java.io.File;
import org.openide.util.Lookup;
import org.openide.util.lookup.Lookups;
import it.tidalwave.util.spi.SimpleFinderSupport;
import it.tidalwave.role.Displayable;
import it.tidalwave.role.SimpleComposite;
import it.tidalwave.role.spi.DefaultDisplayable;
import it.tidalwave.role.spi.DefaultSimpleComposite;
import it.tidalwave.netbeans.capabilitiesprovider.LookupFactory;

/***********************************************************************************************************************
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public final class FileModel4 implements Lookup.Provider
  {
    @Getter
    private final Lookup lookup;
    
    // ...

    //@bluebook-ignore-begin
    private final File file;
    
    private final Displayable displayable;
    
    private final SimpleComposite<FileModel4> composite = new DefaultSimpleComposite<FileModel4>(
        new SimpleFinderSupport<FileModel4>()
          {
            @Override @Nonnull
            protected List<? extends FileModel4> computeResults() 
              {
                final List<FileModel4> result = new ArrayList<FileModel4>();
                final File[] children = file.listFiles();

                if (children != null)
                  {
                    for (final File child : children)
                      {
                        result.add(new FileModel4(child.getAbsolutePath()));
                      }
                  }

                return result;
              }
          });
    //@bluebook-ignore-end
    
    public FileModel4 (final @Nonnull String path) 
      {        
        file = new File(path);
        displayable = new DefaultDisplayable(file.getName());
        lookup = LookupFactory.createLookup(this, Lookups.fixed(displayable, composite));
      }    
    
    //@bluebook-ignore-begin
    @Nonnull
    public String getPath()
      {
        return file.getAbsolutePath();  
      }

    @Override @Nonnull
    public String toString()
      {
        return String.format("FileModel4@%x[%s]", System.identityHashCode(this), getPath());  
      }
    //@bluebook-ignore-end
  }
